<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versione %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 è Software Libero ma il suo sviluppo richiede tempo prezioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&quot;%1&quot;&gt;Fai una donazione&lt;/a&gt; per aiutare lo sviluppo di %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Rilasciato sotto licenza &lt;a href=&quot;%1&quot;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Quello che hai sempre voluto sapere su %1 e non hai mai osato chiedere</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Prova le mie altre applicazioni:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, un&apos;app per YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, un player musicale per YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduci %1 nella tua lingua usando %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenziato a: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Inserisci i dati della tua licenza:</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Codice:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Compra %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Questa demo è scaduta.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Senza una licenza, l&apos;applicazione scadrà in %1 giorni.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Acquistando la versione completa, supporterai anche il lavoro che ho fatto per creare %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usa la demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Inserisci la tua licenza</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Compra una licenza</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>La versione completa ti permette di aggiungere più di %1 tracce alla playlist e di ascoltare la tua musica senza interruzioni.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Compra su %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Continua</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popolarità</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordine invertito</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordina per</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Continua</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Contatore tracce</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Contatore Album</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popolarità</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordine Invertito</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordina per</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Indietro</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Torna indietro</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Benvenuto su &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 deve indicizzare la tua collezione musicale.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Usa la collezione iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Usa %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Scegli una cartella...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 si connetterà a Last.fm e invierà i nomi degli artisti e titoli degli album per scaricare le copertine, le biografie e altro.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Se hai dei </translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Dov&apos;è la tua collezione musicale?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Seleziona la posizione della tua collezione musicale.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Trova la tua collezione</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Pulisci</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>L&apos;indicizzazione è già in corso</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 sta indicizzando la tua collezione musicale.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 sta utilizzando &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; per catalogare la tua musica.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Questa operazione richiede del tempo a seconda delle dimensioni della tua collezione e della velocità della tua connessione.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Ti va un caffé?</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Download dell&apos;aggiornamento in corso...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Trascina qui per aggiungere alla playlist</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artisti</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Cartelle</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Play/Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ferma</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Ferma dopo questa traccia</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Traccia successiva</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Traccia precedente</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumenta il volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Abbassa il volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Disattiva audio</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Vai avanti</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Vai indietro</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Autenticazione non riuscita</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Accedi a %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Nome &amp;utente:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Password:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Crea un account su %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Hai dimenticato il &lt;a href=&apos;%1&apos;&gt;nome utente&lt;/a&gt; o la &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Indietro</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Torna alla schermata precedente</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Mostra informazioni su questa traccia</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>P&amp;recedente</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Torna alla traccia precedente</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Successiva</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Vai alla traccia successiva</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Play</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Inizia a riprodurre</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vai in modalità schermo intero</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Cancella</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Rimuovi le tracce selezionate dalla playlist</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Sposta in &amp;su</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Sposta in su le tracce selezionate della playlist</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sposta in &amp;giù</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Sposta in giù le tracce selezionate della playlist</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ciao</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Cambia la cartella della collezione musicale...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Seleziona una cartella diversa per la tua collezione musicale</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sito &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 sul Web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Fai una &amp;donazione</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Supporta lo sviluppo di %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Informazioni</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informazioni su %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Pulisci</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Rimuovi tutte le tracce dalla playlist</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Casuale</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Modalità casuale della playlist</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Ripeti la prima traccia dopo che tutte le altre sono state riprodotte</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Disattiva l&apos;audio</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Applicazione</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Controlli</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Playlist</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Premi %1 per abbassare il volume, %2 per abbassarlo</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Apertura di %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Aggiornamento della collezione...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Aggiornamento della collezione - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Collezione aggiornata</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Errore fatale: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Esci dalla modalità &amp;schermo intero</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo rimanente: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Il suono è disabilitato</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Il suono è ripristinato</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Compra la versione completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>È disponibile la versione %2 di %1.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Ricordamelo più tardi</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Finestra</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Contrai</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Compra %1</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Ferma dopo questa traccia</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Invia i titoli delle tracce ascoltate a %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Esci da %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Segnala un problema...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>%1 ho finito di scannerizzare la tua collezione musicale</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>Ti piace %1?</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Trascina qui</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Playlist terminata</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Questa è solo la version demo di %1</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Ti permette di ascoltare qualche traccia in modo da testare l&apos;applicazione e capire se ti piace.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Compra la versione completa</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Una nuova versione di %1 è disponibile!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 è ora disponibile. Tu hai la %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Vuoi scaricare ora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Salta questa versione</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Ricordamelo più tardi</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installa aggiornamento</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Questa demo è limitata a solo %1 tracce nella playlist.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>La playlist è vuota</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 tracce - Durata totale: %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>La ricerca non ha prodotto risultati</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Tracce</translation>
    </message>
</context>
</TS>